@@ -1,7 +1,7 @@
 import logging
 import math
 from numbers import Number
-from operator import add
+import operator
 import os
 
 from bokeh.layouts import column, row
@@ -113,7 +113,7 @@ class Occupancy(DashboardComponent):
                 tools="",
                 id="bk-occupancy-plot",
                 x_axis_type="datetime",
-                **kwargs
+                **kwargs,
             )
             rect = fig.rect(
                 source=self.source, x="x", width="ms", y="y", height=1, color="color"
@@ -193,7 +193,7 @@ class ProcessingHistogram(DashboardComponent):
                 name="processing_hist",
                 y_axis_label="frequency",
                 tools="",
-                **kwargs
+                **kwargs,
             )
 
             self.root.xaxis.minor_tick_line_alpha = 0
@@ -236,7 +236,7 @@ class NBytesHistogram(DashboardComponent):
                 id="bk-nbytes-histogram-plot",
                 y_axis_label="frequency",
                 tools="",
-                **kwargs
+                **kwargs,
             )
 
             self.root.xaxis[0].formatter = NumeralTickFormatter(format="0.0 b")
@@ -290,7 +290,7 @@ class BandwidthTypes(DashboardComponent):
                 id="bk-bandwidth-type-plot",
                 name="bandwidth_type_histogram",
                 y_range=["a", "b"],
-                **kwargs
+                **kwargs,
             )
             rect = fig.rect(
                 source=self.source,
@@ -364,7 +364,7 @@ class BandwidthWorkers(DashboardComponent):
                 name="bandwidth_worker_heatmap",
                 x_range=["a", "b"],
                 y_range=["a", "b"],
-                **kwargs
+                **kwargs,
             )
             fig.xaxis.major_label_orientation = -math.pi / 12
             rect = fig.rect(
@@ -458,7 +458,7 @@ class CurrentLoad(DashboardComponent):
                 id="bk-nprocessing-plot",
                 name="processing_hist",
                 width=int(width / 2),
-                **kwargs
+                **kwargs,
             )
             rect = processing.rect(
                 source=self.source,
@@ -477,7 +477,7 @@ class CurrentLoad(DashboardComponent):
                 id="bk-nbytes-worker-plot",
                 width=int(width / 2),
                 name="nbytes_hist",
-                **kwargs
+                **kwargs,
             )
             rect = nbytes.rect(
                 source=self.source,
@@ -495,7 +495,7 @@ class CurrentLoad(DashboardComponent):
                 id="bk-cpu-worker-plot",
                 width=int(width / 2),
                 name="cpu_hist",
-                **kwargs
+                **kwargs,
             )
             rect = cpu.rect(
                 source=self.source,
@@ -585,7 +585,7 @@ class CurrentLoad(DashboardComponent):
                     or inf
                 )
 
-                if limit > max_limit:
+                if limit > max_limit and limit != inf:
                     max_limit = limit
 
                 if nb > limit:
@@ -637,7 +637,7 @@ class StealingTimeSeries(DashboardComponent):
             height=150,
             tools="",
             x_range=x_range,
-            **kwargs
+            **kwargs,
         )
         fig.line(source=self.source, x="time", y="idle", color="red")
         fig.line(source=self.source, x="time", y="saturated", color="green")
@@ -691,7 +691,7 @@ class StealingEvents(DashboardComponent):
             height=250,
             tools="",
             x_range=x_range,
-            **kwargs
+            **kwargs,
         )
 
         fig.circle(
@@ -787,7 +787,7 @@ class Events(DashboardComponent):
             height=height,
             tools="",
             x_range=x_range,
-            **kwargs
+            **kwargs,
         )
 
         fig.circle(
@@ -797,7 +797,7 @@ class Events(DashboardComponent):
             color="color",
             size=50,
             alpha=0.5,
-            legend="action",
+            **{"legend_field" if BOKEH_VERSION >= "1.4" else "legend": "action"},
         )
         fig.yaxis.axis_label = "Action"
         fig.legend.location = "top_left"
@@ -873,6 +873,7 @@ class TaskStream(DashboardComponent):
         clear_interval = parse_timedelta(clear_interval, default="ms")
         self.clear_interval = clear_interval
         self.last = 0
+        self.last_seen = 0
 
         self.source, self.root = task_stream_figure(clear_interval, **kwargs)
 
@@ -899,16 +900,31 @@ class TaskStream(DashboardComponent):
             if not rectangles["start"]:
                 return
 
-            # If there has been a significant delay then clear old rectangles
-            first_end = min(map(add, rectangles["start"], rectangles["duration"]))
-            if first_end > self.last:
-                last = self.last
-                self.last = first_end
-                if first_end > last + self.clear_interval * 1000:
-                    self.offset = min(rectangles["start"])
-                    self.source.data.update({k: [] for k in rectangles})
+            # If it has been a while since we've updated the plot
+            if time() > self.last_seen + self.clear_interval:
+                new_start = min(rectangles["start"]) - self.offset
+                old_start = min(self.source.data["start"])
+                old_end = max(
+                    map(
+                        operator.add,
+                        self.source.data["start"],
+                        self.source.data["duration"],
+                    )
+                )
+
+                density = (
+                    sum(self.source.data["duration"])
+                    / len(self.workers)
+                    / (old_end - old_start)
+                )
+
+                # If whitespace is more than 3x the old width
+                if (new_start - old_end) > (old_end - old_start) * 2 or density < 0.05:
+                    self.source.data.update({k: [] for k in rectangles})  # clear
+                    self.offset = min(rectangles["start"])  # redefine offset
 
             rectangles["start"] = [x - self.offset for x in rectangles["start"]]
+            self.last_seen = time()
 
             # Convert to numpy for serialization speed
             if n >= 10 and np:
@@ -958,7 +974,7 @@ def task_stream_figure(clear_interval="20s", **kwargs):
         x_axis_type="datetime",
         min_border_right=35,
         tools="",
-        **kwargs
+        **kwargs,
     )
 
     rect = root.rect(
@@ -1058,7 +1074,7 @@ class TaskGraph(DashboardComponent):
             color=node_colors,
             source=self.node_source,
             view=node_view,
-            legend="state",
+            **{"legend_field" if BOKEH_VERSION >= "1.4" else "legend": "state"},
         )
         self.root.xgrid.grid_line_color = None
         self.root.ygrid.grid_line_color = None
@@ -1202,7 +1218,7 @@ class TaskProgress(DashboardComponent):
             y_range=y_range,
             toolbar_location=None,
             tools="",
-            **kwargs
+            **kwargs,
         )
         self.root.line(  # just to define early ranges
             x=[0, 0.9], y=[-1, 0], line_color="#FFFFFF", alpha=0.0
@@ -1368,7 +1384,7 @@ class MemoryUse(DashboardComponent):
             y_range=DataRange1d(),
             toolbar_location=None,
             outline_line_color=None,
-            **kwargs
+            **kwargs,
         )
 
         self.root.add_glyph(
@@ -1492,7 +1508,7 @@ class WorkerTable(DashboardComponent):
             reorderable=True,
             sortable=True,
             width=width,
-            **dt_kwargs
+            **dt_kwargs,
         )
 
         for name in table_names:
@@ -1511,7 +1527,7 @@ class WorkerTable(DashboardComponent):
             reorderable=True,
             sortable=True,
             width=width,
-            **dt_kwargs
+            **dt_kwargs,
         )
 
         hover = HoverTool(
@@ -1532,7 +1548,7 @@ class WorkerTable(DashboardComponent):
             height=60,
             width=width,
             tools="",
-            **kwargs
+            **kwargs,
         )
         mem_plot.circle(
             source=self.source, x="memory_percent", y=0, size=10, fill_alpha=0.5
@@ -1561,7 +1577,7 @@ class WorkerTable(DashboardComponent):
             height=60,
             width=width,
             tools="",
-            **kwargs
+            **kwargs,
         )
         cpu_plot.circle(
             source=self.source, x="cpu_fraction", y=0, size=10, fill_alpha=0.5
@@ -1707,7 +1723,7 @@ def status_doc(scheduler, extra, doc):
             n_rectangles=dask.config.get(
                 "distributed.scheduler.dashboard.status.task-stream-length"
             ),
-            clear_interval="10s",
+            clear_interval="5s",
             sizing_mode="stretch_both",
         )
         task_stream.update()
