@@ -171,6 +171,7 @@ class CountsJSON(RequestHandler):
         released = 0
         waiting = 0
         waiting_data = 0
+        desired_workers = scheduler.adaptive_target()
 
         for ts in scheduler.tasks.values():
             if ts.exception_blame is not None:
@@ -203,6 +204,7 @@ class CountsJSON(RequestHandler):
             "waiting": waiting,
             "waiting_data": waiting_data,
             "workers": len(scheduler.workers),
+            "desired_workers": desired_workers,
         }
         self.write(response)
 
@@ -239,26 +241,36 @@ class _PrometheusCollector(object):
     def collect(self):
         from prometheus_client.core import GaugeMetricFamily
 
-        yield GaugeMetricFamily(
-            "dask_scheduler_workers",
-            "Number of workers connected.",
-            value=len(self.server.workers),
-        )
         yield GaugeMetricFamily(
             "dask_scheduler_clients",
             "Number of clients connected.",
             value=len(self.server.clients),
         )
+
         yield GaugeMetricFamily(
-            "dask_scheduler_received_tasks",
-            "Number of tasks received at scheduler",
-            value=len(self.server.tasks),
+            "dask_scheduler_desired_workers",
+            "Number of workers scheduler needs for task graph.",
+            value=self.server.adaptive_target(),
         )
-        yield GaugeMetricFamily(
-            "dask_scheduler_unrunnable_tasks",
-            "Number of unrunnable tasks at scheduler",
-            value=len(self.server.unrunnable),
+
+        tasks = GaugeMetricFamily(
+            "dask_scheduler_workers",
+            "Number of workers known by scheduler.",
+            labels=["state"],
         )
+        tasks.add_metric(["connected"], len(self.server.workers))
+        tasks.add_metric(["saturated"], len(self.server.saturated))
+        tasks.add_metric(["idle"], len(self.server.idle))
+        yield tasks
+
+        tasks = GaugeMetricFamily(
+            "dask_scheduler_tasks",
+            "Number of tasks known by scheduler.",
+            labels=["state"],
+        )
+        tasks.add_metric(["received"], len(self.server.tasks))
+        tasks.add_metric(["unrunnable"], len(self.server.unrunnable))
+        yield tasks
 
 
 class PrometheusHandler(RequestHandler):
