@@ -44,6 +44,13 @@ def serialize_numpy_ndarray(x):
     else:
         dt = (0, x.dtype.str)
 
+    # Only serialize non-broadcasted data for arrays with zero strided axes
+    if 0 in x.strides:
+        broadcast_to = (x.shape, x.flags.writeable)
+        x = x[tuple(slice(None) if s != 0 else slice(1) for s in x.strides)]
+    else:
+        broadcast_to = None
+
     if not x.shape:
         # 0d array
         strides = x.strides
@@ -68,6 +75,9 @@ def serialize_numpy_ndarray(x):
 
     header = {"dtype": dt, "shape": x.shape, "strides": strides}
 
+    if broadcast_to is not None:
+        header["broadcast_to"] = broadcast_to
+
     if x.nbytes > 1e5:
         frames = frame_split_size([data])
     else:
@@ -97,6 +107,11 @@ def deserialize_numpy_ndarray(header, frames):
             header["shape"], dtype=dt, buffer=frames[0], strides=header["strides"]
         )
 
+        if header.get("broadcast_to"):
+            shape, writeable = header["broadcast_to"]
+            x = np.broadcast_to(x, shape)
+            x.setflags(write=writeable)
+
         return x
 
 
