@@ -15,7 +15,7 @@ from tornado.locks import Event
 
 import dask
 from distributed.diagnostics import SchedulerPlugin
-from distributed import Nanny, rpc, Scheduler, Worker, Client
+from distributed import Nanny, rpc, Scheduler, Worker, Client, wait
 from distributed.core import CommClosedError
 from distributed.metrics import time
 from distributed.protocol.pickle import dumps
@@ -30,33 +30,30 @@ from distributed.utils_test import (  # noqa: F401
 
 
 @gen_cluster(nthreads=[])
-def test_nanny(s):
-    n = yield Nanny(s.address, nthreads=2, loop=s.loop)
+async def test_nanny(s):
+    async with Nanny(s.address, nthreads=2, loop=s.loop) as n:
+        async with rpc(n.address) as nn:
+            assert n.is_alive()
+            assert s.nthreads[n.worker_address] == 2
+            assert s.workers[n.worker_address].nanny == n.address
 
-    with rpc(n.address) as nn:
-        assert n.is_alive()
-        assert s.nthreads[n.worker_address] == 2
-        assert s.workers[n.worker_address].nanny == n.address
+            await nn.kill()
+            assert not n.is_alive()
+            assert n.worker_address not in s.nthreads
+            assert n.worker_address not in s.workers
 
-        yield nn.kill()
-        assert not n.is_alive()
-        assert n.worker_address not in s.nthreads
-        assert n.worker_address not in s.workers
+            await nn.kill()
+            assert not n.is_alive()
+            assert n.worker_address not in s.nthreads
+            assert n.worker_address not in s.workers
 
-        yield nn.kill()
-        assert not n.is_alive()
-        assert n.worker_address not in s.nthreads
-        assert n.worker_address not in s.workers
+            await nn.instantiate()
+            assert n.is_alive()
+            assert s.nthreads[n.worker_address] == 2
+            assert s.workers[n.worker_address].nanny == n.address
 
-        yield nn.instantiate()
-        assert n.is_alive()
-        assert s.nthreads[n.worker_address] == 2
-        assert s.workers[n.worker_address].nanny == n.address
-
-        yield nn.terminate()
-        assert not n.is_alive()
-
-    yield n.close()
+            await nn.terminate()
+            assert not n.is_alive()
 
 
 @gen_cluster(nthreads=[])
@@ -115,7 +112,7 @@ def test_nanny_process_failure(c, s):
     assert not os.path.exists(second_dir)
     assert not os.path.exists(first_dir)
     assert first_dir != n.worker_dir
-    ww.close_rpc()
+    yield ww.close_rpc()
     s.stop()
 
 
@@ -290,6 +287,60 @@ def test_nanny_terminate(c, s, a):
         assert "memory" in out.lower()
 
 
+@gen_cluster(
+    nthreads=[("127.0.0.1", 1)] * 8,
+    client=True,
+    Worker=Nanny,
+    worker_kwargs={"memory_limit": 2e8},
+    timeout=20,
+    clean_kwargs={"threads": False},
+)
+async def test_nanny_throttle(c, s, *workers):
+    # Verify that get_data requests are throttled when the worker
+    # with the data is at high-memory by
+    # 1. Allocation some data on a worker
+    # 2. Pausing that worker
+    # 3. Requesting data from that worker from many other workers
+    a = workers[0]
+    proc = a.process.pid
+    size = 1000
+
+    def data(size):
+        return b"0" * size
+
+    def patch(dask_worker):
+        # Patch paused and memory_monitor on the one worker
+        # This is is very fragile, since a refactor of memory_monitor to
+        # remove _memory_monitoring will break this test.
+        dask_worker._memory_monitoring = True
+        dask_worker.paused = True
+
+    def check(dask_worker):
+        return dask_worker.paused
+
+    futures = [
+        c.submit(data, size, workers=[a.worker_address], pure=False) for i in range(4)
+    ]
+    await wait(futures)
+    await c.run(patch, workers=[a.worker_address])
+    paused = await c.run(check, workers=[a.worker_address])
+    assert paused[a.worker_address]
+
+    await c.run(lambda: logging.getLogger("distributed.worker").setLevel(logging.DEBUG))
+    # Cluster is in the correct state, now for the test.
+    n = len(workers)
+    result = c.map(
+        lambda x, i: x[i],
+        [futures[0]] * n,
+        range(n),
+        workers=[w.worker_address for w in workers[1:]],
+    )
+    await result[0]
+    wlogs = await c.get_worker_logs(workers=[a.worker_address])
+    wlogs = "\n".join(x[1] for x in wlogs[a.worker_address])
+    assert "throttling" in wlogs.lower()
+
+
 @gen_cluster(nthreads=[], client=True)
 def test_avoid_memory_monitor_if_zero_limit(c, s):
     nanny = yield Nanny(s.address, loop=s.loop, memory_limit=0)
